#include "ZepicsBD.h"
      implicit none
c      
#include  "ZepTrackv.h"
#include  "Zcnfig.h"
#include  "ZepManager.h"
      character*100  dsn1
      MediaDir(1) = '$EPICSTOP/Data/Media'
      write(0,*) ' Enter path to the config file'
      read(*,'(a)') dsn1
      call eprcnf(dsn1)
      call epOutCnf(0, 1000, 6)
      end

